// src/component/Article/Article.stories.js
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import README from './README.md.txt';
import Article from './Article';

// スナップショットテスト時はInfoアドオンが記述されないように分岐しています
const withReadme = text => (story, context) => (process.env.NODE_ENV === 'test' ? (story()) : withInfo(text)(story)(context));

const article = {
  id: '0',
  title: '',
  contents: '本文です。',
  img: '',
};

export default article;

storiesOf('Article', module)
  .addDecorator(withReadme(README))
  .add('本文のみ', () => (
    <Article article={article} />
  ))
  .add('タイトルあり', () => {
    const articleWithTitle = { ...article, title: 'タイトル' };
    return (
      <Article article={articleWithTitle} />
    );
  })
  .add('画像あり', () => {
    const imageUrl = 'http://via.placeholder.com/350x150';
    const articleWithImage = { ...article, title: 'タイトル', img: imageUrl };
    return (
      <Article article={articleWithImage} />
    );
  });
